Changelog
---------

0.1.7 (2018-04-26)
~~~~~~~~~~~~~~~~~~~~~

- Fixes external links not working on IE 11.
  [href]

0.1.6 (2018-03-28)
~~~~~~~~~~~~~~~~~~~~~

- Scrolls to top whenever we load the iframe.
  [href]

0.1.5 (2018-03-23)
~~~~~~~~~~~~~~~~~~~~~

- Fixes streetnames getting wrapped.
  [href]

0.1.4 (2018-03-20)
~~~~~~~~~~~~~~~~~~~~~

- Adjusts framed style.
  [href]

- Discards completely irrevant search results.
  [href]

- Adds support for streets without addresses.
  [href]

0.1.3 (2018-03-08)
~~~~~~~~~~~~~~~~~~~~~

- Fixes iframe height being calculated incorrectly.
  [href]

0.1.2 (2018-03-01)
~~~~~~~~~~~~~~~~~~~~~

- Applies Winterthur's CD to the framed version.
  [href]

0.1.1 (2018-02-06)
~~~~~~~~~~~~~~~~~~~~~

- Adds a frame-ancestors whitelist.
  [href]

0.1.0 (2018-01-31)
~~~~~~~~~~~~~~~~~~~~~

- Initial Release.
  [href]

